"use client";

import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";

import { ContentLines } from "@/components/shared/content-lines";
import { Card } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Link, Locale } from "@/i18n/routing";
import { useSimilar } from "@/servers/data/use-similar";

// Define proper types for the product
interface Product {
	id: string;
	product_slug: string;
	name_en: string;
	name_ar: string;
	base_price: number;
	images: Array<{
		image_path: string;
		name: string;
	}>;
}

function RelatedProductsClient({
	currentId,
}: {
	currentId: string;
}) {
	const locale = useLocale() as Locale;
	const t = useTranslations("SimilarProducts");
	const { similar } = useSimilar(currentId, 3);

	const ProductCard = ({ product }: { product: Product }) => {
		const imagePath = product?.images?.[0]?.image_path;
		const imageSrc = imagePath ? `${ImageBaseUrl}${imagePath}` : "/default-image.png";
		const imageAlt = product?.images?.[0]?.name || "Product image";

		return (
			<Card className="flex-col h-[400px] overflow-hidden rounded-md border-none bg-white shadow-md">
				<div className="relative h-[250px] w-full">
					<Image
						src={imageSrc}
						alt={imageAlt}
						fill
						className="object-cover"
					/>
				</div>
				<div className="flex flex-1 flex-col items-center gap-2 p-4">
					<h3 className="text-lg font-semibold">
						{locale === "ar" ? product?.name_ar : product?.name_en}
					</h3>
					<div className="flex items-center gap-2">
						<div className="flex items-center gap-2">
							<Image
								src={"/coins/Saudi_Riyal.jpg"}
								alt="Saudi_Riyal"
								width={16}
								height={16}
							/>
							<span className="text-sm text-center font-bold text-[#2895C8]">
								{product?.base_price}
							</span>
						</div>
					</div>
				</div>
			</Card>

		);
	};

	return (
		<section className="container mx-auto flex max-w-7xl flex-col py-24">
			<div className="mb-6 text-center">
				<ContentLines
					title={t("OtherProducts")}
					underlineColor="custom-primary-accent"
					centered
					textColor="text-custom-primary-accent"
				/>
				<h2 className="text-4xl font-bold">
					{t("SimilarProducts")}
				</h2>
			</div>

			{similar.length > 0 ? (
				<div className="grid mt-4 gap-6 sm:grid-cols-1 md:grid-cols-2 lg:grid-cols-3">
					{similar?.map((product: Product) => (
						<Link
							href={`/products/${product?.product_slug}` as any}
							key={product?.id}
						>
							<ProductCard product={product} />
						</Link>
					))}
				</div>
			) : (
				<div className="flex items-center justify-center">
					<p className="text-md font-thin text-gray-500">
						{t("No similar products found")}
					</p>
				</div>
			)}
		</section>
	);
}

export default RelatedProductsClient;
